@@ -56,7 +56,12 @@ class Connection(object):
     :keyword transport_options: A dict of additional connection arguments to
       pass to alternate kombu channel implementations.  Consult the transport
       documentation for available options.
-    :keyword insist: *Deprecated*
+    :keyword heartbeat: Heartbeat interval in int/float seconds.
+        Note that if heartbeats are enabled then the :meth:`heartbeat_check`
+        method must be called at an interval twice the frequency of the
+        heartbeat: e.g. if the heartbeat is 10, then the heartbeats must be
+        checked every 5 seconds (the rate can also be controlled by
+        the ``rate`` argument to :meth:`heartbeat_check``).
 
     .. note::
 
@@ -94,13 +99,13 @@ class Connection(object):
             password=None, virtual_host=None, port=None, insist=False,
             ssl=False, transport=None, connect_timeout=5,
             transport_options=None, login_method=None, uri_prefix=None,
-            **kwargs):
+            heartbeat=0, **kwargs):
         # have to spell the args out, just to get nice docstrings :(
         params = {'hostname': hostname, 'userid': userid,
                   'password': password, 'virtual_host': virtual_host,
                   'port': port, 'insist': insist, 'ssl': ssl,
                   'transport': transport, 'connect_timeout': connect_timeout,
-                  'login_method': login_method}
+                  'login_method': login_method, 'heartbeat': heartbeat}
         if hostname and '://' in hostname:
             if '+' in hostname[:hostname.index('://')]:
                 # e.g. sqla+mysql://root:masterkey@localhost/
@@ -127,7 +132,7 @@ class Connection(object):
         self.declared_entities = set()
 
     def _init_params(self, hostname, userid, password, virtual_host, port,
-            insist, ssl, transport, connect_timeout, login_method):
+            insist, ssl, transport, connect_timeout, login_method, heartbeat):
         self.hostname = hostname
         self.userid = userid
         self.password = password
@@ -138,6 +143,7 @@ class Connection(object):
         self.connect_timeout = connect_timeout
         self.ssl = ssl
         self.transport_cls = transport
+        self.heartbeat = heartbeat
 
     def _debug(self, msg, ident='[Kombu connection:0x%(id)x] ', **kwargs):
         if self._logger:  # pragma: no cover
@@ -159,6 +165,20 @@ class Connection(object):
                     '[Kombu channel:%(channel_id)s] ')
         return chan
 
+    def heartbeat_check(self, rate=2):
+        """Verify that hartbeats are sent and received.
+
+        If the current transport does not support heartbeats then
+        this is a noop operation.
+
+        :keyword rate: Rate is how often the tick is called
+            compared to the actual heartbeat value.  E.g. if
+            the heartbeat is set to 3 seconds, and the tick
+            is called every 3 / 2 seconds, then the rate is 2.
+
+        """
+        return self.transport.heartbeat_check(self.connection, rate=rate)
+
     def drain_events(self, **kwargs):
         """Wait for a single event from the server.
 
@@ -399,7 +419,8 @@ class Connection(object):
                 ('connect_timeout', self.connect_timeout),
                 ('transport_options', self.transport_options),
                 ('login_method', self.login_method or D.get('login_method')),
-                ('uri_prefix', self.uri_prefix))
+                ('uri_prefix', self.uri_prefix),
+                ('heartbeat', self.heartbeat))
         return info
 
     def info(self):
@@ -630,6 +651,10 @@ class Connection(object):
     def eventmap(self):
         return self.transport.eventmap(self.connection)
 
+    @property
+    def supports_heartbeats(self):
+        return self.transport.supports_heartbeats
+
     @property
     def is_evented(self):
         return getattr(self.transport, 'on_poll_start', None)
