@@ -57,16 +57,16 @@ else:
 # cPickle.loads does not support buffer() objects,
 # but we can just create a StringIO and use load.
 if sys.version_info[0] == 3:
-    from io import StringIO
+    from io import BytesIO
 else:
     try:
-        from cStringIO import StringIO  # noqa
+        from cStringIO import StringIO as BytesIO # noqa
     except ImportError:
-        from StringIO import StringIO   # noqa
+        from StringIO import StringIO  as BytesIO # noqa
 
 
 def pickle_loads(s, load=pickle_load):
-    return load(StringIO(s))
+    return load(BytesIO(s))
 
 
 class SerializerRegistry(object):
