@@ -264,7 +264,7 @@ def reprkwargs(kwargs, sep=', ', fmt='%s=%s'):
     return sep.join(fmt % (k, _safe_repr(v)) for k, v in kwargs.iteritems())
 
 
-def reprcall(name, args=(), kwargs=(), sep=', '):
+def reprcall(name, args=(), kwargs={}, sep=', '):
     return '%s(%s%s%s)' % (name, sep.join(map(_safe_repr, args or ())),
                            (args and kwargs) and sep or '',
                            reprkwargs(kwargs, sep))
